
# CODE OF CONDUCT

We value the participation of every member of our community and want to ensure that every contributor has an enjoyable and fulfilling experience.
Accordingly, everyone who participates in the project is expected to show respect and courtesy to other community members at all times.

Kirstie Whitaker, as PI of this project, and all project members, are dedicated to a ***harassment-free experience for everyone***, regardless of gender, gender identity and expression, sexual orientation, disability, physical appearance, body size, race, age or religion. **We do not tolerate harassment by and/or of members of our community in any form**.

We are particularly motivated to support new and/or anxious collaborators, people who are looking to learn and develop their skills, and anyone who has experienced discrimination in the past.

To make clear what is expected, we ask all members of the community to conform to the following Code of Conduct.

* [1 Introduction](#1-introduction)
* [2 Code of Conduct](#2-code-of-conduct)
  * [2.1 Expected Behaviour](#21-expected-behaviour)
  * [2.2 Unacceptable Behaviour](#22-unacceptable-behaviour)
  * [2.3 Consequences of Unacceptable Behaviour](#23-consequences-of-unacceptable-behaviour)
  * [2.4 Feedback](#24-feedback)
* [3 Acknowledgements](#5-acknowledgements)

## 1 Introduction

The project is a community-oriented and -led project.
We value the involvement of everyone in the community.
We are committed to creating a friendly and respectful place for learning, teaching and contributing.
All participants in our in-person events and online communications are expected to show respect and courtesy to others at all times.

To make clear what is expected, everyone participating in activities associated with the project is required to conform to this Code of Conduct.
This Code of Conduct applies to all spaces managed by the project including, but not limited to, in-person focus groups and workshops, and communications online via GitHub.

The lead investigator of the project - Dr Kirstie Whitaker - is responsible for enforcing the Code of Conduct.
She can be contacted by emailing [kwhitaker@turing.ac.uk](mailto:kwhitaker@turing.ac.uk).
You may contact [Anna Krystalli](mailto:a.krystalli@sheffield.ac.uk) or [Ben Murton](mailto:bmurton@turing.ac.uk) if you would prefer not to contact Dr Whitaker.

Reports may be reviewed by other members of the core development team, unless there is a conflict of interest, and will be kept confidential.

## 2 Code of Conduct

The NeuralPlayground team are dedicated to providing a welcoming and supportive environment for all people, regardless of background or identity.
As such, we do not tolerate behaviour that is disrespectful to our community members or that excludes, intimidates, or causes discomfort to others.
We do not tolerate discrimination or harassment based on characteristics that include, but are not limited to: gender identity and expression, sexual orientation, disability, physical appearance, body size, citizenship, nationality, ethnic or social origin, pregnancy, familial status, veteran status, genetic information, religion or belief (or lack thereof), membership of a national minority, property, age, education, socio-economic status, technical choices, and experience level.

Everyone who participates in the NeuralPlayground project activities is required to conform to this Code of Conduct.
This Code of Conduct applies to all spaces managed by the NeuralPlayground project including, but not limited to, in person focus groups and workshops, and communications online via GitHub.
By participating, contributors indicate their acceptance of the procedures by which the NeuralPlayground project core development team resolves any Code of Conduct incidents, which may include storage and processing of their personal information.

### 2.1 Expected Behaviour

We are confident that our community members will together build a supportive and collaborative atmosphere at our events and during online communications.
The following bullet points set out explicitly what we hope you will consider to be appropriate community guidelines:

* **Be respectful of different viewpoints and experiences**. Do not engage in homophobic, racist, transphobic, ageist, ableist, sexist, or otherwise exclusionary behaviour.
* **Use welcoming and inclusive language**. Exclusionary comments or jokes, threats or violent language are not acceptable. Do not address others in an angry, intimidating, or demeaning manner. Be considerate of the ways the words you choose may impact others. Be patient and respectful of the fact that English is a second (or third or fourth!) language for some participants.
* **Do not harass people**. Harassment includes unwanted physical contact, sexual attention, or repeated social contact. Know that consent is explicit, conscious and continuous—not implied. If you are unsure whether your behaviour towards another person is welcome, ask them. If someone tells you to stop, do so.
* **Respect the privacy and safety of others**. Do not take photographs of others without their permission. Do not share other participant’s personal experiences without their express permission. Note that posting (or threatening to post) personally identifying information of others without their consent ("doxing") is a form of harassment.
* **Be considerate of others’ participation**. Everyone should have an opportunity to be heard. In update sessions, please keep comments succinct so as to allow maximum engagement by all participants. Do not interrupt others on the basis of disagreement; hold such comments until they have finished speaking.
* **Don’t be a bystander**. If you see something inappropriate happening, speak up. If you don't feel comfortable intervening but feel someone should, please feel free to ask a member of the Code of Conduct response team for support.
* As an overriding general rule, please **be intentional in your actions and humble in your mistakes**.

All interactions should be professional regardless of platform: either online or in-person.
See [this explanation of the four social rules](https://www.recurse.com/manual#sub-sec-social-rules) - no feigning surprise, no well-actually's, no back-seat driving, no subtle -isms - for further recommendations for inclusive behaviours.

### 2.2 Unacceptable Behaviour

Examples of unacceptable behaviour by NeuralPlayground community members at any project event or platform include:

* written or verbal comments which have the effect of excluding people on the basis of membership of any specific group
* causing someone to fear for their safety, such as through stalking, following, or intimidation
* violent threats or language directed against another person
* the display of sexual or violent images
* unwelcome sexual attention
* nonconsensual or unwelcome physical contact
* sustained disruption of talks, events or communications
* insults or put downs
* sexist, racist, homophobic, transphobic, ableist, or exclusionary jokes
* excessive swearing
* incitement to violence, suicide, or self-harm
* continuing to initiate interaction (including photography or recording) with someone after being asked to stop
* publication of private communication without consent


## 3 Acknowledgements

This code is adapted from the [the Turing Way]. 
This code is adapted from the Carpentries Code of Conduct with sections from the Alan Turing Institute Data Study Group Code of Conduct. Both are used under the creative commons attribution license.

The Carpentries Code of Conduct was adapted from guidelines written by the Django Project, which was itself based on the Ada Initiative template and the PyCon 2013 Procedure for Handling Harassment Incidents. Contributors to the initial document are Adam Obeng, Aleksandra Pawlik, Bill Mills, Carol Willing, Erin Becker, Hilmar Lapp, Kara Woo, Karin Lagesen, Pauline Barmby, Sheila Miguez, Simon Waldman, and Tracy Teal. In 2018, the Code of Conduct was revised to add a summary, straightforward examples of both beneficial and unwanted behaviors, and evaluating intent. Reporting guidelines were also revised to include alternate contact points and a reporting form with the procedure was added. Contributors of these revised documents are Ethan White, Kari L. Jordan, Karin Lagesen, Malvika Sharan, Samantha Ahern, and Simon Waldman. Additional language was added by Otter Tech from the PyCon U.S. 2018 Code of Conduct (licensed CC BY 3.0).

The Turing Institute Data Study Group Code of Conduct was heavily adapted from the Citizen Lab Summer Institute 2017 Code of Conduct and used under a CC BY 2.5 CA license. Citizen Lab based their Code of Conduct on the xvzf Code of Conduct, the Contributor Covenant, the Django Code of Conduct and Reporting Guide and we are also grateful for this guidance from Ada Initiative.

We really appreciate the work that all of the communities linked above have put into creating such a well considered process.

This Code of Conduct is licensed under a Creative Commons Attribution 4.0 International (CC BY 4.0 CA) license which means you are free to share and adapt the work so long as the attribution to this code of conduct and the other resources.
